/*
 * Licensed to the University Corporation for Advanced Internet Development, 
 * Inc. (UCAID) under one or more contributor license agreements.  See the 
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache 
 * License, Version 2.0 (the "License"); you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.internet2.middleware.shibboleth.common.profile;

import org.opensaml.ws.transport.InTransport;
import org.opensaml.ws.transport.OutTransport;

/**
 * Basic interfaces for classes that handler incoming requests.
 * 
 * @param <InTransportType> inbound transport type
 * @param <OutTransportType> outbount transport type
 */
public interface ProfileHandler<InTransportType extends InTransport, OutTransportType extends OutTransport> {

    /**
     * Processes an incoming request.
     * 
     * @param inTransport the incoming request transport
     * @param outTransport the outgoing response transport
     * 
     * @throws ProfileException throw if there was a problem while processing the request
     */
    public void processRequest(InTransportType inTransport, OutTransportType outTransport) throws ProfileException;

}